Module: MissionControl::Jobs::Theme
- Defined in:
- lib/mission_control/jobs/theme.rb,
lib/mission_control/jobs/theme/railtie.rb,
lib/mission_control/jobs/theme/version.rb,
lib/mission_control/jobs/theme/middleware.rb,
lib/mission_control/jobs/theme/configuration.rb,
lib/mission_control/jobs/theme/route_discovery.rb,
lib/generators/mission_control/jobs/theme/install/install_generator.rb
Overview
Inject a custom CSS theme and optional syntax highlighting into the Mission Control Jobs dashboard.
Provides a configuration DSL and Rack middleware that rewrites HTML responses served by Engine.
Defined Under Namespace
Modules: RouteDiscovery Classes: Configuration, Error, InstallGenerator, Middleware, Railtie
Constant Summary collapse
- VERSION =
"0.3.0"
Class Method Summary collapse
-
.configuration ⇒ Configuration
Return the current configuration, initializing it on first access.
-
.configure {|config| ... } ⇒ void
Yield the current configuration for modification.
-
.reset_configuration! ⇒ Configuration
Reset the configuration to defaults.
Class Method Details
.configuration ⇒ Configuration
Return the current configuration, initializing it on first access.
47 48 49 |
# File 'lib/mission_control/jobs/theme.rb', line 47 def self.configuration @configuration ||= Configuration.new end |
.configure {|config| ... } ⇒ void
This method returns an undefined value.
Yield the current configuration for modification.
40 41 42 |
# File 'lib/mission_control/jobs/theme.rb', line 40 def self.configure yield(configuration) end |
.reset_configuration! ⇒ Configuration
Reset the configuration to defaults.
54 55 56 |
# File 'lib/mission_control/jobs/theme.rb', line 54 def self.reset_configuration! @configuration = Configuration.new end |